==> hs-mwc-random-0.4.1.1.tbz: lib/mwc-random-0.4.1.1/register.sh <==
#!/bin/sh

echo 'name: mwc-random
version: 0.4.1.1
license: BSD3
copyright: 2009 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: http://darcs.serpentine.com/mwc-random
package-url:
description: This package contains code for generating high quality random
             numbers that follow either a uniform or normal distribution.  The
             generated numbers are suitable for use in statistical applications.
             .
             The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
             multiply-with-carry generator, which has a period of 2^8222 and
             fares well in tests of randomness.  It is also extremely fast,
             between 2 and 3 times faster than the Mersenne Twister.
             .
             Compared to the mersenne-random package, this package has a more
             convenient API, is faster, and supports more statistical
             distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: System.Random.MWC
hidden-modules:
import-dirs: /usr/local/lib/mwc-random-0.4.1.1/ghc-6.10.4
library-dirs: /usr/local/lib/mwc-random-0.4.1.1/ghc-6.10.4
hs-libraries: HSmwc-random-0.4.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 time-1.1.4 uvector-0.1.1.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/mwc-random-0.4.1.1/html/mwc-random.haddock
haddock-html: /usr/local/share/doc/mwc-random-0.4.1.1/html' | /usr/local/bin/ghc-pkg update -

==> hs-mwc-random-0.7.0.1.tbz: lib/mwc-random-0.7.0.1/register.sh <==
#!/bin/sh

echo 'name: mwc-random
version: 0.7.0.1
license: BSD3
copyright: 2009, 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: http://darcs.serpentine.com/mwc-random
package-url:
description: This package contains code for generating high quality random
             numbers that follow either a uniform or normal distribution.  The
             generated numbers are suitable for use in statistical applications.
             .
             The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
             multiply-with-carry generator, which has a period of 2^8222 and
             fares well in tests of randomness.  It is also extremely fast,
             between 2 and 3 times faster than the Mersenne Twister.
             .
             Compared to the mersenne-random package, this package has a more
             convenient API, is faster, and supports more statistical
             distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: System.Random.MWC
hidden-modules:
import-dirs: /usr/local/lib/mwc-random-0.7.0.1/ghc-6.10.4
library-dirs: /usr/local/lib/mwc-random-0.7.0.1/ghc-6.10.4
              /usr/local/lib
hs-libraries: HSmwc-random-0.7.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.1.0.0 primitive-0.3 time-1.1.4 vector-0.6.0.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/mwc-random-0.7.0.1/html/mwc-random.haddock
haddock-html: /usr/local/share/doc/mwc-random-0.7.0.1/html' | /usr/local/bin/ghc-pkg update -
